summaryrefslogtreecommitdiffstats
path: root/class
diff options
context:
space:
mode:
authorRemi Collet <fedora@famillecollet.com>2014-07-27 18:39:58 +0200
committerRemi Collet <fedora@famillecollet.com>2014-07-27 18:39:58 +0200
commita30604293878c9cf4794c00d289442f9e0a20311 (patch)
tree46e7f32280a0e089e5ff1f4efb2189b8890782b2 /class
parenta725ecce477cf3630160f779504a7bfa9d94c9ce (diff)
fix distro order in list
Diffstat (limited to 'class')
-rw-r--r--class/TableRpmRepo.php8
1 files changed, 6 insertions, 2 deletions
diff --git a/class/TableRpmRepo.php b/class/TableRpmRepo.php
index 17e29d2..1a30242 100644
--- a/class/TableRpmRepo.php
+++ b/class/TableRpmRepo.php
@@ -78,16 +78,20 @@ class TableRpmRepo extends CommonTable
/**
* Retrieve all the known repository
*
* @param boolean $active true for only active repo (false for all)
*
* @return hastable of id => hastable
*/
- function getAllRepo($active=true)
+ function getAllRepo($active=true, $onlysrc=true)
{
$crit = array("ORDER" => 'id');
if ($active) {
$crit['active'] = 1;
}
+ if ($onlysrc) {
+ $crit['id'] = '>0';
+ }
return $this->getArray($crit);
}
@@ -78,16 +78,20 @@ class TableRpmRepo extends CommonTable
* Retrieve all the known repository
*
- * @param boolean $active true for only active repo (false for all)
+ * @param boolean $active true for only active repo (false for all)
+ * @param boolean $onlysrc true for only sources repo (false for all)
*
* @return hastable of id => hastable